From: David Howells <dhowells@redhat.com>
To: torvalds@osdl.org, akpm@osdl.org, mingo@elte.hu,
benh@kernel.crashing.org
Cc: linux-kernel@vger.kernel.org, uclinux-dev@uclinux.org,
dhowells@redhat.com
Subject: [PATCH 3/3] FRV: Mark __do_IRQ() deprecated
Date: Fri, 08 Sep 2006 16:32:42 +0100 [thread overview]
Message-ID: <20060908153242.21015.66379.stgit@warthog.cambridge.redhat.com> (raw)
In-Reply-To: <20060908153236.21015.56106.stgit@warthog.cambridge.redhat.com>
From: David Howells <dhowells@redhat.com>
Mark __do_IRQ() as being deprecated (as Ben Herrenschmidt says it is).
Rename the real __do_IRQ() to __do_IRQ_deprecated() and wrap this in an inline
function called __do_IRQ() that is deprecated to prevent generic_handle_irq()
from giving deprecation warnings on every file.
Signed-Off-By: David Howells <dhowells@redhat.com>
---
include/linux/irq.h | 11 +++++++++--
kernel/irq/handle.c | 6 ++++--
2 files changed, 13 insertions(+), 4 deletions(-)
diff --git a/include/linux/irq.h b/include/linux/irq.h
index 48d3cb3..83bf988 100644
--- a/include/linux/irq.h
+++ b/include/linux/irq.h
@@ -319,9 +319,16 @@ handle_irq_name(void fastcall (*handle)(
/*
* Monolithic do_IRQ implementation.
* (is an explicit fastcall, because i386 4KSTACKS calls it from assembly)
+ * - This is obsolete; generic_handle_irq() should be used instead.
*/
#ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_IRQ
-extern fastcall unsigned int __do_IRQ(unsigned int irq, struct pt_regs *regs);
+extern fastcall unsigned int __do_IRQ_deprecated(unsigned int irq, struct pt_regs *regs);
+
+static inline __deprecated fastcall
+unsigned int __do_IRQ(unsigned int irq, struct pt_regs *regs)
+{
+ return __do_IRQ_deprecated(irq, regs);
+}
#endif
/*
@@ -340,7 +347,7 @@ #else
if (likely(desc->handle_irq))
desc->handle_irq(irq, desc, regs);
else
- __do_IRQ(irq, regs);
+ __do_IRQ_deprecated(irq, regs);
#endif
}
diff --git a/kernel/irq/handle.c b/kernel/irq/handle.c
index 2e9e800..f3b1615 100644
--- a/kernel/irq/handle.c
+++ b/kernel/irq/handle.c
@@ -151,7 +151,7 @@ irqreturn_t handle_IRQ_event(unsigned in
#ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_IRQ
/**
* __do_IRQ - original all in one highlevel IRQ handler
* @irq: the interrupt number
* @regs: pointer to a register structure
*
@@ -161,8 +161,10 @@ #ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_I
*
* This is the original x86 implementation which is used for every
* interrupt type.
+ *
+ * This is obsolete; generic_handle_irq() should be used instead.
*/
-fastcall unsigned int __do_IRQ(unsigned int irq, struct pt_regs *regs)
+fastcall unsigned int __do_IRQ_deprecated(unsigned int irq, struct pt_regs *regs)
{
struct irq_desc *desc = irq_desc + irq;
struct irqaction *action;
prev parent reply other threads:[~2006-09-08 15:33 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2006-09-08 15:32 [PATCH 1/3] FRV: Improve FRV's use of generic IRQ handling David Howells
2006-09-08 15:32 ` [PATCH 2/3] FRV: Permit __do_IRQ() to be dispensed with David Howells
2006-09-09 5:12 ` Ingo Molnar
2006-09-09 7:26 ` Benjamin Herrenschmidt
2006-09-10 14:34 ` Daniel Walker
2006-09-11 5:33 ` Ingo Molnar
2006-09-21 13:12 ` David Howells
2006-09-21 21:59 ` Benjamin Herrenschmidt
2006-09-11 9:47 ` David Howells
2006-09-11 15:33 ` Daniel Walker
2006-09-08 15:32 ` David Howells [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20060908153242.21015.66379.stgit@warthog.cambridge.redhat.com \
--to=dhowells@redhat.com \
--cc=akpm@osdl.org \
--cc=benh@kernel.crashing.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mingo@elte.hu \
--cc=torvalds@osdl.org \
--cc=uclinux-dev@uclinux.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -151,7 +151,7 @@ irqreturn_t handle_IRQ_event(unsigned in
#ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_IRQ
/**
- * __do_IRQ - original all in one highlevel IRQ handler
+ * __do_IRQ_deprecated - original all in one highlevel IRQ handler
* @irq: the interrupt number
* @regs: pointer to a register structure
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®